==> cmptoast-android-1.0.3-sources.jar: androidMain/multiplatform/network/cmptoast/MainActivity.kt <==
package multiplatform.network.cmptoast

import android.app.Activity
import android.content.Context
import android.graphics.drawable.GradientDrawable
import android.os.Build
import android.util.Log
import android.view.Gravity
import android.view.LayoutInflater
import android.widget.TextView
import android.widget.Toast
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.toArgb
import androidx.compose.ui.unit.TextUnit
import androidx.compose.ui.unit.sp


fun toast(
    context: Context,
    message: String = "",
    duration: ToastDuration = ToastDuration.Short,
    gravity: ToastGravity = ToastGravity.Bottom,
    backgroundColor: Color? = Color.Black,
    textColor: Color? = Color.White,
    padding: ToastPadding? = null,
    cornerRadius: Int? = 100,
    textSize: TextUnit = 14.sp,
    topPadding: Int = 100,
    bottomPadding: Int = 100
) {
    val mToast: Toast?

    val mGravity: Int = when (gravity) {
        ToastGravity.Top -> {
            Gravity.TOP
        }
        ToastGravity.Center -> {
            Gravity.CENTER
        }
        ToastGravity.Bottom -> {
            Gravity.BOTTOM
        }
    }

    val toastDuration = when(duration) {
        ToastDuration.Long -> Toast.LENGTH_LONG
        ToastDuration.Short -> Toast.LENGTH_SHORT
    }

    if (backgroundColor != null) {
        val layout = (context.getSystemService(Context.LAYOUT_INFLATER_SERVICE) as LayoutInflater).inflate(R.layout.toast_custom, null)
        val text = layout.findViewById<TextView>(R.id.text)
        text.text = message

        // Create a new shape drawable with the custom corner radius
        val shapeDrawable = GradientDrawable()
        shapeDrawable.shape = GradientDrawable.RECTANGLE
        shapeDrawable.setColor(backgroundColor.toArgb())
        shapeDrawable.cornerRadius = cornerRadius?.toFloat() ?: 100f

        // Set toast inside padding
        val toastPadding = padding ?: ToastPadding(top = 30, bottom = 30, left = 60, right = 60)
        layout.background = shapeDrawable

        layout.setPadding(toastPadding.left, toastPadding.top, toastPadding.right, toastPadding.bottom)
        text.textSize = textSize.value

        if (textColor != null) {
            text.setTextColor(textColor.toArgb())
        }

        mToast = Toast(context)
        mToast.duration = toastDuration

        mToast.view = layout
    } else {
        mToast = Toast.makeText(context, message, toastDuration)
        mToast.duration = toastDuration
        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.R) {
            val textView: TextView = mToast?.view!!.findViewById(android.R.id.message)
            textView.textSize = textSize.value
            if (textColor != null) {
                textView.setTextColor(textColor.toArgb())
            }
        }
    }

    try {
        when (mGravity) {
            Gravity.CENTER -> {
                mToast?.setGravity(mGravity, 0, 0)
            }
            Gravity.TOP -> {
                mToast?.setGravity(mGravity, 0, topPadding)
            }
            else -> {
                mToast?.setGravity(mGravity, 0, bottomPadding)
            }
        }
    } catch (e: Exception,) {
        Log.e("Toast", "Exception : ${e.message}")
    }

    if (context is Activity) {
        context.runOnUiThread { mToast?.show() }
    } else {
        mToast?.show()
    }
}

==> cmptoast-android-1.0.7-sources.jar: androidMain/multiplatform/network/cmptoast/MainActivity.kt <==
package multiplatform.network.cmptoast

import android.app.Activity
import android.content.Context
import android.graphics.drawable.GradientDrawable
import android.os.Build
import android.util.Log
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import android.widget.Toast
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.ImageBitmap
import androidx.compose.ui.graphics.asAndroidBitmap
import androidx.compose.ui.graphics.toArgb
import androidx.compose.ui.unit.TextUnit
import androidx.compose.ui.unit.sp


fun toast(
    context: Context,
    message: String = "",
    duration: ToastDuration = ToastDuration.Short,
    gravity: ToastGravity = ToastGravity.Bottom,
    backgroundColor: Color? = Color.Black,
    textColor: Color? = Color.White,
    padding: ToastPadding? = null,
    cornerRadius: Int? = 100,
    textSize: TextUnit = 14.sp,
    topPadding: Int = 100,
    bottomPadding: Int = 100,
    icon: ImageBitmap? = null,
    iconSizeDp: Int = 24
) {
    val mToast: Toast?

    val mGravity: Int = when (gravity) {
        ToastGravity.Top -> {
            Gravity.TOP
        }
        ToastGravity.Center -> {
            Gravity.CENTER
        }
        ToastGravity.Bottom -> {
            Gravity.BOTTOM
        }
    }

    val toastDuration = when(duration) {
        ToastDuration.Long -> Toast.LENGTH_LONG
        ToastDuration.Short -> Toast.LENGTH_SHORT
    }

    if (backgroundColor != null) {
        val layout = (context.getSystemService(Context.LAYOUT_INFLATER_SERVICE) as LayoutInflater).inflate(R.layout.toast_custom, null)
        val text = layout.findViewById<TextView>(R.id.text)
        text.text = message

        val iconView = layout.findViewById<ImageView>(R.id.icon)
        if (icon != null) {
            val bitmap = icon.asAndroidBitmap()
            iconView.setImageBitmap(bitmap)
            iconView.visibility = View.VISIBLE

            // Convert dp to pixels
            val density = context.resources.displayMetrics.density
            val iconSizePx = (iconSizeDp * density).toInt()

            // Set icon size
            val layoutParams = iconView.layoutParams
            layoutParams.width = iconSizePx
            layoutParams.height = iconSizePx
            iconView.layoutParams = layoutParams
        } else {
            iconView.visibility = View.GONE
        }

        // Create a new shape drawable with the custom corner radius
        val shapeDrawable = GradientDrawable()
        shapeDrawable.shape = GradientDrawable.RECTANGLE
        shapeDrawable.setColor(backgroundColor.toArgb())
        shapeDrawable.cornerRadius = cornerRadius?.toFloat() ?: 100f

        // Set toast inside padding
        val toastPadding = padding ?: ToastPadding(top = 30, bottom = 30, left = 60, right = 60)
        layout.background = shapeDrawable

        layout.setPadding(toastPadding.left, toastPadding.top, toastPadding.right, toastPadding.bottom)
        text.textSize = textSize.value

        if (textColor != null) {
            text.setTextColor(textColor.toArgb())
        }

        mToast = Toast(context)
        mToast.duration = toastDuration

        mToast.view = layout
    } else {
        mToast = Toast.makeText(context, message, toastDuration)
        mToast.duration = toastDuration
        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.R) {
            val textView: TextView = mToast?.view!!.findViewById(android.R.id.message)
            textView.textSize = textSize.value
            if (textColor != null) {
                textView.setTextColor(textColor.toArgb())
            }
        }
    }

    try {
        when (mGravity) {
            Gravity.CENTER -> {
                mToast?.setGravity(mGravity, 0, 0)
            }
            Gravity.TOP -> {
                mToast?.setGravity(mGravity, 0, topPadding)
            }
            else -> {
                mToast?.setGravity(mGravity, 0, bottomPadding)
            }
        }
    } catch (e: Exception,) {
        Log.e("Toast", "Exception : ${e.message}")
    }

    if (context is Activity) {
        context.runOnUiThread { mToast?.show() }
    } else {
        mToast?.show()
    }
}
